@@ -36,7 +36,7 @@ def Populate():
     """
     # Iterate through the relvar dictionary to get each table
     print("Populating Flatland DB...")
-    here = Path(__file__).parent
+    here = Path(__file__).parent / "Population"
     pop_dirs = [
         here / "Connector", here / "Decorator", here / "Drawing", here / "Node",
     ]
